
// $Id: Cache.cpp,v 1.12 2013/04/29 18:27:10 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Debug.h"
#include "Cache.h"
#include "XmlDef.h"
#include "XmlDocument.h"

//____________________________________________________________________________
bool Cache::read( File file )
{

    Debug::Throw( "Cache::read.\n" );
    if( !file.isEmpty() ) file_ = file;
    if( file_.isEmpty() ) return false;

    // make sure file is hidden (windows only)
    if( file_.localName().startsWith( '.' ) )
    { file_.setHidden(); }

    // parse the file
    XmlDocument document;
    {
        QFile qfile( file_ );
        if( !document.setContent( &qfile ) )
        {
            Debug::Throw() << document.error() << endl;
            return false;
        }
    }

    // look for relevant element
    QDomNodeList topNodes = document.elementsByTagName( XML::CACHE );
    if( topNodes.isEmpty() ) return false;
    for(QDomNode node = topNodes.at(0).firstChild(); !node.isNull(); node = node.nextSibling() )
    {

        QDomElement element = node.toElement();
        if( element.isNull() ) continue;

        // special options
        if( element.tagName() == XML::FILEINFO_CACHE ) fileInfoCache_ = FileInfoCache( element );
        else if( element.tagName() == XML::REVISION_CACHE ) revisionCache_ = RevisionCache( element );
        else Debug::Throw() << "Cache::read - unrecognized tag " << element.tagName() << endl;

    }

    return true;
}

//____________________________________________________________________________
bool Cache::write( File file ) const
{

    if( file.isEmpty() ) file = file_;
    if( file.isEmpty() ) return false;

    // create document and read
    XmlDocument document;
    {
        QFile qtfile( file );
        document.setContent( &qtfile );
    }

    // create main element
    QDomElement top = document.createElement( XML::CACHE );
    top.appendChild( fileInfoCache().domElement( document ) );
    top.appendChild( revisionCache().domElement( document ) );

    // append top node to document and write
    document.replaceChild( top );
    {
        QFile qfile( file );
        if( !qfile.open( QIODevice::WriteOnly ) ) return false;
        qfile.write( document.toByteArray() );
    }

    return true;
}
