/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "FileSelectionDialog.h"
#include "FileSelectionDialog.moc"

#include "BaseIcons.h"
#include "IconEngine.h"
#include "TreeView.h"
#include "XmlOptions.h"

#include <QLabel>

//____________________________________________________________________________
FileSelectionDialog::FileSelectionDialog( QWidget* parent, const FileInfoModel::List& files ):
CustomDialog( parent )
{

    Debug::Throw( "FileSelectionDialog::FileSelectionDialog.\n" );

    // horizontal layout for list and comments
    QHBoxLayout* hLayout( new QHBoxLayout() );
    hLayout->setSpacing( 5 );
    hLayout->setMargin( 0 );
    mainLayout().addLayout( hLayout, 1 );

    // file list
    QVBoxLayout* vLayout = new QVBoxLayout();
    vLayout->setSpacing( 5 );
    vLayout->setMargin( 0 );
    hLayout->addLayout( vLayout );

    vLayout->addWidget( new QLabel( tr( "Selected files:" ), this ) );
    vLayout->addWidget( list_ = new TreeView( this ), 1 );
    _list().setSelectionMode( QAbstractItemView::MultiSelection );
    _list().setModel( &model_ );

    // mask
    _list().setMask( XmlOptions::get().get<unsigned int>( "FILE_LIST_MASK" ) );

    model_.add( files );
    model_.sort( FileInfoModel::FILE, Qt::DescendingOrder );
    _list().resizeColumnToContents( FileInfoModel::FILE );
    _list().selectAll();

    // vertical layout for selection buttons and comments
    vLayout = new QVBoxLayout();
    vLayout->setSpacing( 5 );
    vLayout->setMargin( 0 );
    hLayout->addLayout( vLayout );

    // work layout
    work_ = new QVBoxLayout();
    work_->setSpacing( 5 );
    work_->setMargin( 0 );
    vLayout->addLayout( work_, 1 );

    // select all
    QPushButton* button;
    vLayout->addWidget( button = new QPushButton( tr( "Select All" ), this ) );
    button->setToolTip( tr( "Select all files in list" ) );
    connect( button, SIGNAL(clicked()), &_list(), SLOT(selectAll()) );

    // deselect all
    vLayout->addWidget( clearSelectionButton_ = new QPushButton( tr( "Clear Selection" ), this ) );
    clearSelectionButton_->setToolTip( tr( "Deselect all files in list" ) );
    connect( clearSelectionButton_, SIGNAL(clicked()), _list().selectionModel(), SLOT(clear()) );

    // connection
    connect( _list().selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)), SLOT(_updateButtons()) );
    _updateButtons();

}

//____________________________________________________________________________
FileInfoModel::List FileSelectionDialog::selectedFiles( void ) const
{ return _model().get( _list().selectionModel()->selectedRows() ); }

//____________________________________________________________________
void FileSelectionDialog::_updateButtons( void )
{
    Debug::Throw( "FileSelectionDialog::_updateButtons.\n" );
    bool has_selection( !_list().selectionModel()->selectedRows().empty() );
    clearSelectionButton_->setEnabled( has_selection );
    okButton().setEnabled( has_selection );
}
