// $Id: LogDialog.cpp,v 1.9 2013/11/15 14:50:39 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "LogDialog.h"
#include "LogDialog.moc"
#include "LogWidget.h"
#include "Singleton.h"
#include "XmlOptions.h"

#include <QLayout>
#include <QShortcut>

//____________________________________________________________
LogDialog::LogDialog( QWidget* parent ):
CustomDialog( parent, CloseButton )
{

    Debug::Throw( "LogDialog::LogDialog.\n" );
    setWindowTitle( tr( "Log Information - Cvswatch" ) );
    setOptionName( "LOG_DIALOG" );

    // custom margins
    layout()->setMargin(0);
    layout()->setSpacing(0);
    buttonLayout().setMargin(5);

    // editor
    editor_ = new LogWidget( this );
    editor_->setOptionName( "LOG_WIDGET" );
    mainLayout().addWidget( editor_ );

    // configuration
    connect( Singleton::get().application(), SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );

    // actions
    QActionGroup *group = new QActionGroup( this );
    group->setExclusive( true );
    connect( group, SIGNAL(triggered(QAction*)), SLOT(_changeVerbosity(QAction*)) );

    addAction( verbosityLowAction_ = new QAction( tr( "Low" ), this ) );
    group->addAction( verbosityLowAction_ );
    verbosityLowAction_->setCheckable( true );

    addAction( verbosityHighAction_ = new QAction( tr( "High" ), this ) );
    group->addAction( verbosityHighAction_ );
    verbosityHighAction_->setCheckable( true );

    _updateConfiguration();

    // ok button
    connect( &okButton(), SIGNAL(pressed()), SLOT(close()) );

    // close accelerator
    new QShortcut( QKeySequence::Close, this, SLOT(close()) );

}

//_____________________________________________________________
void LogDialog::closeEvent( QCloseEvent* event )
{
    Debug::Throw( "LogDialog::closeEvent.\n" );
    emit dialogHidden();
    return CustomDialog::closeEvent( event );
}

//_____________________________________________________________
void LogDialog::_updateConfiguration( void )
{

    Debug::Throw( "LogDialog::_updateConfiguration.\n" );

    editor_->setVerbosity( (CvsInterface::Verbosity) XmlOptions::get().get<int>( "VERBOSITY" )  );
    switch( editor_->verbosity() )
    {

        default:
        case CvsInterface::LOW:
        verbosityLowAction_->setChecked( true );
        break;

        case CvsInterface::HIGH:
        verbosityHighAction_->setChecked( true );
        break;

    }

}

//_____________________________________________________________
void LogDialog::_changeVerbosity( QAction* action )
{

    Debug::Throw( "LogDialog::_changeVerbosity.\n" );
    if( action == verbosityLowAction_ ) editor_->setVerbosity( CvsInterface::LOW );
    else if( action == verbosityHighAction_ ) editor_->setVerbosity( CvsInterface::HIGH );
    XmlOptions::get().set<int>( "VERBOSITY", editor_->verbosity() ) ;

}
