// $Id: Menu.cpp,v 1.47 2013/11/15 14:50:39 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Application.h"
#include "Debug.h"
#include "DebugMenu.h"
#include "DefaultHelpText.h"
#include "FileList.h"
#include "FileSelectionFrame.h"
#include "HelpText.h"
#include "HelpManager.h"
#include "LogDialog.h"
#include "MainWindow.h"
#include "Menu.h"
#include "Menu.moc"
#include "RecentFilesMenu.h"
#include "RevisionFrame.h"
#include "Singleton.h"
#include "XmlOptions.h"
#include "Util.h"
#include "ViewModeMenu.h"

//__________________________________________________
Menu::Menu( QWidget* parent ):
    QMenuBar( parent ),
    Counter( "Menu" )
{

    Debug::Throw( "Menu::Menu" );

    // generic menu
    QMenu *menu;

    Application& application( *Singleton::get().application<Application>() );
    MainWindow& mainwindow( *static_cast<MainWindow*>( window() ) );
    FileSelectionFrame& selectionframe( mainwindow.selectionFrame() );
    RevisionFrame& revisionFrame( mainwindow.revisionFrame() );

    // create file menu
    menu = addMenu( tr( "File" ) );
    menu->addAction( &mainwindow.openAction() );

    // open previous menu
    recentFilesMenu_ = new RecentFilesMenu( this, application.recentFiles() );
    connect( recentFilesMenu_, SIGNAL(fileSelected(FileRecord)), &mainwindow, SLOT(open(FileRecord)) );
    menu->addMenu( recentFilesMenu_ );

    menu->addAction( &mainwindow.reloadAction() );

    // quit button
    menu->addSeparator();
    menu->addAction( &application.closeAction() );

    // windows menu
    menu = addMenu( tr( "View" ) );
    menu->addMenu( viewModeMenu_ = new ViewModeMenu( this ) );
    viewModeMenu_->setTitle( tr( "View Mode" ) );
    menu->addSeparator();
    menu->addAction( &selectionframe.hiddenFilesAction() );
    menu->addAction( &revisionFrame.visibilityAction() );
    menu->addSeparator();
    menu->addAction( &mainwindow.showLogDialogAction() );
    menu->addAction( &mainwindow.showCommandDialogAction() );

    // create preferences menu
    menu = addMenu( tr( "Settings" ) );

    QMenu* subMenu = menu->addMenu( tr( "Log Verbosity" ) );
    subMenu->addAction( &mainwindow.logDialog().verbosityLowAction() );
    subMenu->addAction( &mainwindow.logDialog().verbosityHighAction() );
    menu->addSeparator();

    menu->addAction( &application.configurationAction() );

    // help manager
    BASE::HelpManager* help( new BASE::HelpManager( this ) );
    help->setWindowTitle( tr( "Cvswatch Handbook" ) );
    help->install( helpText );
    help->install( BASE::helpText, false );

    // create help menu
    menu = addMenu( tr( "Help" ) );
    menu->addAction( &help->displayAction() );
    menu->addSeparator();
    menu->addAction( &application.aboutAction() );
    menu->addAction( &application.aboutQtAction() );

    // debug menu
    menu->addSeparator();
    DebugMenu *debugMenu( new DebugMenu( menu ) );
    menu->addAction( debugMenu->menuAction() );
    debugMenu->menuAction()->setVisible( false );

    debugMenu->addAction( &mainwindow.fileInfoCacheAction() );
    debugMenu->addAction( &mainwindow.revisionCacheAction() );

}
