
// $Id: Revision.cpp,v 1.17 2013/04/29 18:27:10 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Revision.h"
#include "Str.h"
#include "XmlDef.h"
#include "XmlString.h"

//_________________________________________________________________
Revision::Revision( const QDomElement& element ):
Counter( "Revision" )
{
    Debug::Throw( "Revision::Revision (dom) .\n" );

    // parse attributes
    QDomNamedNodeMap attributes( element.attributes() );
    for( unsigned int i=0; i<attributes.length(); i++ )
    {
        QDomAttr attribute( attributes.item( i ).toAttr() );
        if( attribute.isNull() ) continue;
        QString name( attribute.name() );
        QString value( attribute.value() );

        if( name == XML::NAME ) setName( XmlString( value ).toText() );
        else if( name == XML::AUTHOR ) setAuthor( XmlString( value ).toText() );
        else if( name == XML::TIME ) setTimeStamp( value.toInt() );
        else Debug::Throw(0) << "unrecognized attachment attribute: \"" << name << "\"\n";
    }

    // parse children elements
    for(QDomNode child_node = element.firstChild(); !child_node.isNull(); child_node = child_node.nextSibling() )
    {
        QDomElement child_element = child_node.toElement();
        if( child_element.tagName() == XML::COMMENTS )
        { setComments( XmlString( child_element.text() ).toText() ); }
        else Debug::Throw(0) << "unrecognized child " << child_element.tagName() << ".\n";
    }

}

//_________________________________________________________________
QDomElement Revision::domElement( QDomDocument& parent ) const
{
    Debug::Throw( "Revision::domElement\n" );

    QDomElement out( parent.createElement( XML::REVISION ) );
    out.setAttribute( XML::NAME, XmlString( name() ).toXml() );
    out.setAttribute( XML::AUTHOR, XmlString( author() ).toXml() );
    out.setAttribute( XML::TIME, QString().setNum( timeStamp() ) );

    if( comments().size())
    {
        out.
            appendChild( parent.createElement(  XML::COMMENTS ) ).
            appendChild( parent.createTextNode( XmlString( comments() ).toXml() ) );
    }

    return out;

}

//_________________________________________________________________
void Revision::setName( QString name )
{
    Debug::Throw( "Revision::setName.\n" );
    QString local( name );
    local.replace( ".", " " );
    QTextStream in( &local );

    revision_.clear();
    int i = 0;
    while( in.status() == QTextStream::Ok )
    {
        in >> i;
        if( in.status() == QTextStream::Ok ) revision_ << i;
    }

    name_ = name;
    return;
}

//_________________________________________________________________
void Revision::setTimeStamp( const QString& value )
{
    Debug::Throw( "Revision::setTimeStamp.\n" );

    // need to convert into a time stamp
    // prototype
    // 2007/08/23 14:10:24

    TimeStamp timeStamp;
    QRegExp regExp( "(\\d+)/(\\d+)/(\\d+)\\s+(\\d+):(\\d+):(\\d+)" );
    if( value.indexOf( regExp ) < 0 )
    {
        Debug::Throw(0) << "Revision::setTimeStamp - unable to parse " << value << endl;
        return;
    }

    timeStamp.setYear( regExp.cap(1).toInt() );
    timeStamp.setMonth( regExp.cap(2).toInt() );
    timeStamp.setDay( regExp.cap(3).toInt() );

    timeStamp.setHours( regExp.cap(4).toInt() );
    timeStamp.setMinutes( regExp.cap(5).toInt() );
    timeStamp.setSeconds( regExp.cap(6).toInt() );
    timeStamp.makeTime();

    setTimeStamp( timeStamp );

}
